package ch.hslu.swk.g03.logger.server;

import java.net.URL;
import java.util.Properties;

/**
 * Main LoggerServer Class.
 *
 * @author Felix Rohrer <felix.rohrer@stud.hslu.ch>
 */
public class LoggerServer {

    private static final int MIN_PORT = 0;
    private static final int MAX_PORT = 65536;
    private String logFileName;
    private int tcpPort;
    private String rmiServerName;
    private int rmiPort;

    /**
     * load LoggerServer config from properties-file.
     *
     * @return config successfully loaded
     */
    public final boolean loadSettings() {
	System.out.println("[INFO:LoggerServer] LoadSettings...");
	final Properties mySettings = new Properties();
	try {
	    // load a properties file from class path, inside static method
	    mySettings.load(LoggerServer.class.getClassLoader().getResourceAsStream("server.properties"));
	    
	    // get the property value, set config values
	    setLogFileName(mySettings.getProperty("LogFile"));
	    setTcpPort(Integer.parseInt(mySettings.getProperty("TCPPort")));
	    setRmiServerName(mySettings.getProperty("RMIServerName"));
	    setRmiPort(Integer.parseInt(mySettings.getProperty("RMIPort")));
	} catch (Exception ex) {
	    // load properties-file failed
	    return false;
	}

	// print out property values
	System.out.println(" --> Logfile:    " + getLogFileName());
	System.out.println(" --> TCP-Port:   " + getTcpPort());
	System.out.println(" --> RMI-Server: " + getRmiServerName());
	System.out.println(" --> RMI-Port:   " + getRmiPort());
	return true;
    }

    /**
     * Returns the current RMI-Port number.
     *
     * @return the RMI-Port number
     */
    public final int getRmiPort() {
        return rmiPort;
    }

    /**
     * Set new TCPPort number.
     *
     * @param newRmiPort
     *            the new RMI-Port number to be set
     * @return true if successfully
     */
    public final boolean setRmiPort(final int newRmiPort) {
	if ((newRmiPort > MIN_PORT) && (newRmiPort <= MAX_PORT)) {
	    this.rmiPort = newRmiPort;
	    return true;
	} else {
	    return false;
	}
    }    


    /**
     * @return the logFileName
     */
    public final String getLogFileName() {
	return logFileName;
    }

    /**
     * Set new Filename.
     *
     * @param newLogFileName
     *            the logFileName to set
     * @return true if successfully
     */
    public final boolean setLogFileName(final String newLogFileName) {
	if (newLogFileName.length() > 0) {
	    this.logFileName = newLogFileName;
	    return true;
	} else {
	    return false;
	}
    }

    /**
     * Returns the current TCP-Port number.
     *
     * @return the TCP-Port number
     */
    public final int getTcpPort() {
	return tcpPort;
    }

    /**
     * Set new TCPPort number.
     *
     * @param newTcpPort
     *            the new TCP-Port number to be set
     * @return true if successfully
     */
    public final boolean setTcpPort(final int newTcpPort) {
	if ((newTcpPort > MIN_PORT) && (newTcpPort <= MAX_PORT)) {
	    this.tcpPort = newTcpPort;
	    return true;
	} else {
	    return false;
	}
    }

    /**
     * Get current RMI-Port number.
     *
     * @return the RMI-Port number
     */
    public final String getRmiServerName() {
	return rmiServerName;
    }

    /**
     * Set new RMI-Port number.
     *
     * @param newRmiServerName
     *            the new RMI-Port number to be set
     */
    public final void setRmiServerName(final String newRmiServerName) {
	this.rmiServerName = newRmiServerName;
    }
}
