package ch.hslu.swk.g03.logger.server;

import static org.junit.Assert.*;

import java.util.Properties;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import ch.hslu.swk.g03.logger.server.LoggerServer;

/**
 * @author Felix Rohrer <felix.rohrer@stud.hslu.ch>
 */
public class LoggerServerTest {

    /**
     * @throws java.lang.Exception
     */
    @Before
    public void setUp() throws Exception {
    }

    /**
     * @throws java.lang.Exception
     */
    @After
    public void tearDown() throws Exception {
    }

    @Test
    public void testCreateLoggerServer() {
	// init new LoggerServer
	LoggerServer myServer = new LoggerServer();
	assertTrue(myServer != null);
    }
    
    @Test
    public void testLoadSettings() {
	LoggerServer myServer = new LoggerServer();
	assertTrue(myServer.loadSettings());
    }
    
    @Test
    public void testSettingsGetLogfileName() {
	String myLogfileName = "";
	
	// load expected Logfile from properties file
	Properties mySettings = new Properties();
	try {
	    // load a properties file from class path, inside static method
	    mySettings.load(LoggerServer.class.getClassLoader().getResourceAsStream("server.properties"));
	    // get the property value, set config values
	    myLogfileName = mySettings.getProperty("LogFile");
	} catch (Exception ex) {
	    // load properties-file failed
	    fail();
	}	
	
	LoggerServer myServer = new LoggerServer();
	assertTrue(myServer.loadSettings());
	assertEquals(myLogfileName, myServer.getLogFileName());
    }        
    
    @Test
    public void testSettingsGetTcpPort() {
	int myTcpPort = 0;
	
	Properties mySettings = new Properties();
	try {
	    mySettings.load(LoggerServer.class.getClassLoader().getResourceAsStream("server.properties"));
	    myTcpPort = Integer.parseInt(mySettings.getProperty("TCPPort"));
	} catch (Exception ex) {
	    fail();
	}	

	LoggerServer myServer = new LoggerServer();
	assertTrue(myServer.loadSettings());
	assertEquals(myTcpPort, myServer.getTcpPort());
    }
    
    @Test
    public void testSettingsGetRMIServerName() {
	String myRMIServerName = "";
	
	Properties mySettings = new Properties();
	try {
	    mySettings.load(LoggerServer.class.getClassLoader().getResourceAsStream("server.properties"));
	    myRMIServerName = mySettings.getProperty("RMIServerName");
	} catch (Exception ex) {
	    fail();
	}	

	LoggerServer myServer = new LoggerServer();
	assertTrue(myServer.loadSettings());
	assertEquals(myRMIServerName, myServer.getRmiServerName());
    }
    
    @Test
    public void testSettingsSetGetLogfileName() {
	String myLogfile = "setLogFileNameTest.txt";
	LoggerServer myServer = new LoggerServer();
	assertTrue(myServer.setLogFileName(myLogfile));
	assertEquals(myLogfile, myServer.getLogFileName());
    }
    
    @Test
    public void testSettingsSetGetTcpPort() {
	int myPort = 8080;
	LoggerServer myServer = new LoggerServer();
	assertTrue(myServer.setTcpPort(myPort));
	assertEquals(myPort, myServer.getTcpPort());
    }
    
    @Test
    public void testSettingsSetTcpPortMin() {
	int myPort = 1;
	LoggerServer myServer = new LoggerServer();
	assertTrue(myServer.setTcpPort(myPort));
	assertEquals(myPort, myServer.getTcpPort());
    }    

    @Test
    public void testSettingsSetTcpPortMax() {
	int myPort = 65536;
	LoggerServer myServer = new LoggerServer();
	assertTrue(myServer.setTcpPort(myPort));
	assertEquals(myPort, myServer.getTcpPort());
    }  
    
    @Test
    public void testSettingsSetTcpPortInvalidZero() {
	int oldPort;
	LoggerServer myServer = new LoggerServer();
	oldPort = myServer.getTcpPort();
	assertFalse(myServer.setTcpPort(0));
	assertEquals(oldPort, myServer.getTcpPort());
    } 
    
    @Test
    public void testSettingsSetTcpPortInvalidSubZero() {
	int oldPort;
	LoggerServer myServer = new LoggerServer();
	oldPort = myServer.getTcpPort();
	assertFalse(myServer.setTcpPort(-1));
	assertEquals(oldPort, myServer.getTcpPort());
    }    
    
    @Test
    public void testSettingsSetTcpPortInvalidToHigh() {
	int oldPort;
	LoggerServer myServer = new LoggerServer();
	oldPort = myServer.getTcpPort();
	assertFalse(myServer.setTcpPort(99999));
	assertEquals(oldPort, myServer.getTcpPort());
    }  
    
    
    

    

    
    
}
